/*! 
    \file obb.h
    \brief Definition of an OBB (object Oriented Bounding Box)

*/

#ifndef _OBB_H
#define _OBB_H

#include "base_object.h"
#include "bounding_volume.h"

template<class T> class tList;

//! A class representing an extended bounding volume tree: an obb tree
class OBB : public BoundingVolume {

 public:
  OBB();
  virtual ~OBB();


  inline const Vector* getAxis () const { return this->axis; }
  inline const sVect3D* getHalfLength() const { return this->halfLength; } 

  virtual tList<sVect3D>* getVertices() const { return this->verticesBuffer; }
  virtual void mergeWith(const BoundingVolume &bv);

  virtual void drawBV(int currentDepth, const int depth) const;
  virtual void drawBVPolygon(int currentDepth, const int depth) const;
  virtual void drawBVBlended(int currentDepth, const int depth) const;


 private:
  Vector*          axis;                       //!< Axes of oriented box [x,y,z]
  sVect3D*         halfLength;                 //!< Half lengths of the box

  OBB*             leftNode;                   //!< left node of the tree
  OBB*             rightNode;                  //!< right node of the tree
};

#endif /* _OBB_H */
